@@ -38,24 +38,35 @@ class Mesh:
         self.obstructions = list()
 
     def get_obstruction_mask(self, cell_centered=False) -> np.ndarray:
+        """Marks all cells which are blocked by an obstruction.
+
+        :returns: A 4-dimensional array with time as first and x,y,z as last dimensions. The array depends on time as
+            as obstructions may be hidden as specific points in time.
+        """
+        n_t = next(iter(self.obstructions[0]._boundary_data.values())).times
         shape = self.dimension.shape(cell_centered=cell_centered)
-        mask = np.ones(shape, dtype=bool)
+        mask = np.ones((n_t, shape[0], shape[1], shape[2]), dtype=bool)
+        c = 1 if cell_centered else 0
 
         for obst in self.obstructions:
-            x1, x2 = obst.bound_indices['x']
-            y1, y2 = obst.bound_indices['y']
-            z1, z2 = obst.bound_indices['z']
-            c = 1 if cell_centered else 0
-            mask[x1:max(x2 + c, x1 + 1), y1:max(y2 + c, y1 + 1), z1:max(z2 + c, z1 + 1)] = False
+            for subobst in obst:
+                x1, x2 = subobst.bound_indices['x']
+                y1, y2 = subobst.bound_indices['y']
+                z1, z2 = subobst.bound_indices['z']
+                for t in subobst.visible_times:
+                    mask[t, x1:max(x2 + c, x1 + 1), y1:max(y2 + c, y1 + 1), z1:max(z2 + c, z1 + 1)] = False
 
         return mask
 
-    def get_obstruction_mask_slice(self, orientation: Literal[1, 2, 3], value: float,
-                                   cell_centered=False):
+    def get_obstruction_mask_slice(self, orientation: Literal[1, 2, 3], value: float, cell_centered=False):
+        """Marks all cells of a single slice which are blocked by an obstruction.
+
+        :returns: A 4-dimensional array with time as first and x,y,z as last dimensions. The array depends on time as
+            as obstructions may be hidden as specific points in time.
+        """
         assert orientation in (1, 2, 3), "The slices orientation has to be one of [1,2,3]!"
 
-        slc_index = self.coordinate_to_index((value,), dimension=(orientation - 1,),
-                                             cell_centered=cell_centered)[0]
+        slc_index = self.coordinate_to_index((value,), dimension=(orientation - 1,), cell_centered=cell_centered)[0]
 
         mask_indices = [slice(None)] * 3
         mask_indices[orientation - 1] = slice(slc_index, slc_index + 1, 1)
@@ -64,8 +75,8 @@ class Mesh:
         return np.squeeze(self.get_obstruction_mask(cell_centered=cell_centered)[mask_indices])
 
     def coordinate_to_index(self, coordinate: Tuple[float, ...],
-                            dimension: Tuple[Literal[0, 1, 2, 'x', 'y', 'z'], ...] = (
-                                    'x', 'y', 'z'), cell_centered=False) -> Tuple[int, ...]:
+                            dimension: Tuple[Literal[0, 1, 2, 'x', 'y', 'z'], ...] = ('x', 'y', 'z'),
+                            cell_centered=False) -> Tuple[int, ...]:
         """Finds the nearest point in the mesh's grid and returns its indices.
 
         :param coordinate: Tuple of 3 floats. If the dimension parameter is supplied, up to 2
